@@ -31,7 +31,7 @@ import datetime
 import time
 import collections
 
-VERSION = (0, 2, 9)
+VERSION = (0, 3, 0)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -316,14 +316,8 @@ Date = datetime.date
 Time = datetime.time
 TimeDelta = datetime.timedelta
 Timestamp = datetime.datetime
-def DateFromTicks(ticks):
-    return apply(Date,time.localtime(ticks)[:3])
-def TimeFromTicks(ticks):
-    return apply(Time,time.localtime(ticks)[3:6])
-def TimestampFromTicks(ticks):
-    return apply(Timestamp,time.localtime(ticks)[:6])
 def Binary(b):
-    return bytes(b)
+    return bytearray(b)
 
 class DBAPITypeObject:
     def __init__(self,*values):
@@ -488,7 +482,7 @@ class Connection(object):
             ])
         )
 
-    def _process_messages(self, obj=None):
+    def _process_messages(self, obj):
         errobj = None
         while True:
             code = ord(self._read(1))
@@ -595,18 +589,14 @@ class Connection(object):
                 else:
                     errobj = DatabaseError(message)
             elif code == PG_B_COPY_OUT_RESPONSE:
-                is_binary = data[0] == '\x01'
-                num_columns = _bytes_to_bint(data[1:3])
-                DEBUG_OUTPUT("COPY_OUT_RESPONSE:", is_binary, num_columns)
+                DEBUG_OUTPUT("COPY_OUT_RESPONSE:")
             elif code == PG_COPY_DATA:
                 DEBUG_OUTPUT("COPY_DATA")
                 obj.write(data)
             elif code == PG_COPY_DONE:
                 DEBUG_OUTPUT("COPY_DONE")
             elif code == PG_B_COPY_IN_RESPONSE:
-                is_binary = data[0] == '\x01'
-                num_columns = _bytes_to_bint(data[1:3])
-                DEBUG_OUTPUT("COPY_IN_RESPONSE", is_binary, num_columns)
+                DEBUG_OUTPUT("COPY_IN_RESPONSE")
                 while True:
                     buf = obj.read(8192)
                     if not buf:
@@ -665,7 +655,7 @@ class Connection(object):
         v += b'\x00'
 
         self._write(_bint_to_bytes(len(v) + 4, 4) + v)
-        self._process_messages()
+        self._process_messages(None)
 
     def is_connect(self):
         return bool(self.sock)
@@ -691,20 +681,20 @@ class Connection(object):
     def begin(self):
         DEBUG_OUTPUT('BEGIN')
         self._send_message(PG_F_QUERY, b"BEGIN\x00")
-        self._process_messages()
+        self._process_messages(None)
 
     def commit(self):
         DEBUG_OUTPUT('COMMIT')
         if self.sock:
             self._send_message(PG_F_QUERY, b"COMMIT\x00")
-            self._process_messages()
+            self._process_messages(None)
             self.begin()
 
     def rollback(self):
         DEBUG_OUTPUT('ROLLBACK')
         if self.sock:
             self._send_message(PG_F_QUERY, b"ROLLBACK\x00")
-            self._process_messages()
+            self._process_messages(None)
             self.begin()
 
     def reopen(self):
